@@ -6,4 +6,4 @@ class DjangoSummernoteTest(TestCase):
 
     def test_reverse_url_for_summernote(self):
         url = reverse_lazy('django_summernote-editor', kwargs={'id': 'foobar'})
-        print url
+        print(url)
